@@ -1,31 +1,37 @@
+from abc import ABCMeta, abstractmethod
 from typing import Tuple, Any, Dict
 
-from . import IStartStop
+from .IStartStop import IStartStop
 from pyobs.utils.enums import WeatherSensors
 
 
-class IWeather(IStartStop):
+class IWeather(IStartStop, metaclass=ABCMeta):
     """The module acts as a weather station."""
-    __module__ = 'pyobs.interfaces'
 
-    def get_weather_status(self, **kwargs: Any) -> Dict[str, Any]:
+    __module__ = "pyobs.interfaces"
+
+    @abstractmethod
+    async def get_weather_status(self, **kwargs: Any) -> Dict[str, Any]:
         """Returns status of object in form of a dictionary. See other interfaces for details."""
-        raise NotImplementedError
+        ...
 
-    def is_weather_good(self, **kwargs: Any) -> bool:
+    @abstractmethod
+    async def is_weather_good(self, **kwargs: Any) -> bool:
         """Whether the weather is good to observe."""
-        raise NotImplementedError
+        ...
 
-    def get_current_weather(self, **kwargs: Any) -> Dict[str, Any]:
+    @abstractmethod
+    async def get_current_weather(self, **kwargs: Any) -> Dict[str, Any]:
         """Returns current weather.
 
         Returns:
             Dictionary containing entries for time, good, and sensor, with the latter being another dictionary
             with sensor information, which contain a value and a good flag.
         """
-        raise NotImplementedError
+        ...
 
-    def get_sensor_value(self, station: str, sensor: WeatherSensors, **kwargs: Any) -> Tuple[str, float]:
+    @abstractmethod
+    async def get_sensor_value(self, station: str, sensor: WeatherSensors, **kwargs: Any) -> Tuple[str, float]:
         """Return value for given sensor.
 
         Args:
@@ -35,7 +41,7 @@ class IWeather(IStartStop):
         Returns:
             Tuple of current value of given sensor or None and time of measurement or None.
         """
-        raise NotImplementedError
+        ...
 
 
-__all__ = ['IWeather']
+__all__ = ["IWeather"]
